[project]
name = "{{ project_name }}"
version = "{{ version }}"
description = "{{ description }}"
{% if use_readme %}
readme = "README.md"
{% endif %}
requires-python = ">={{ python_version }}"
authors = [
    { name = "{{ author_name }}", email = "{{ author_email }}" }
]
license = { text = "{{ license }}" }
dependencies = [
    "pyyaml>=6.0",
    "python-dotenv>=1.0.0",
    "kagglehub>=0.2.0",
    {% if project_type == 'ml' %}
    "numpy>=1.24.0",
    "pandas>=2.0.0",
    "scikit-learn>=1.3.0",
    "matplotlib>=3.7.0",
    "seaborn>=0.12.0",
    "requests>=2.30.0",
    "tqdm>=4.65.0",
    {% elif project_type == 'dl' %}
    {% if framework == 'pytorch' %}
    "torch>=2.0.0",
    "torchvision>=0.15.0",
    {% elif framework == 'tensorflow' %}
    "tensorflow>=2.13.0",
    # "keras>=3.0.0", # Optional, included in tf usually
    {% endif %}
    "numpy>=1.24.0",
    "pandas>=2.0.0",
    "matplotlib>=3.7.0",
    "seaborn>=0.12.0",
    "requests>=2.30.0",
    "tqdm>=4.65.0",
    {% endif %}
]

[build-system]
requires = ["hatchling"]
build-backend = "hatchling.build"

{% if use_uv %}
[tool.uv]
managed = true
{% endif %}

